/***************************************************************************//**
* \file CapSense_RegisterMap.h
* \version 7.0
*
* \brief
*   This file provides the definitions for the Component data structure register.
*
* \see CapSense v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSense_REGISTER_MAP_H)
#define CY_SENSE_CapSense_REGISTER_MAP_H

#include <cytypes.h>
#include "CapSense_Configuration.h"
#include "CapSense_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define CapSense_CONFIG_ID_VALUE                            (CapSense_dsRam.configId)
#define CapSense_CONFIG_ID_OFFSET                           (0u)
#define CapSense_CONFIG_ID_SIZE                             (2u)
#define CapSense_CONFIG_ID_PARAM_ID                         (0x87000000u)

#define CapSense_DEVICE_ID_VALUE                            (CapSense_dsRam.deviceId)
#define CapSense_DEVICE_ID_OFFSET                           (2u)
#define CapSense_DEVICE_ID_SIZE                             (2u)
#define CapSense_DEVICE_ID_PARAM_ID                         (0x8B000002u)

#define CapSense_HW_CLOCK_VALUE                             (CapSense_dsRam.hwClock)
#define CapSense_HW_CLOCK_OFFSET                            (4u)
#define CapSense_HW_CLOCK_SIZE                              (2u)
#define CapSense_HW_CLOCK_PARAM_ID                          (0x86000004u)

#define CapSense_TUNER_CMD_VALUE                            (CapSense_dsRam.tunerCmd)
#define CapSense_TUNER_CMD_OFFSET                           (6u)
#define CapSense_TUNER_CMD_SIZE                             (2u)
#define CapSense_TUNER_CMD_PARAM_ID                         (0xA1000006u)

#define CapSense_SCAN_COUNTER_VALUE                         (CapSense_dsRam.scanCounter)
#define CapSense_SCAN_COUNTER_OFFSET                        (8u)
#define CapSense_SCAN_COUNTER_SIZE                          (2u)
#define CapSense_SCAN_COUNTER_PARAM_ID                      (0x85000008u)

#define CapSense_STATUS_VALUE                               (CapSense_dsRam.status)
#define CapSense_STATUS_OFFSET                              (12u)
#define CapSense_STATUS_SIZE                                (4u)
#define CapSense_STATUS_PARAM_ID                            (0xCB00000Cu)

#define CapSense_WDGT_ENABLE0_VALUE                         (CapSense_dsRam.wdgtEnable[0u])
#define CapSense_WDGT_ENABLE0_OFFSET                        (16u)
#define CapSense_WDGT_ENABLE0_SIZE                          (4u)
#define CapSense_WDGT_ENABLE0_PARAM_ID                      (0xE6000010u)

#define CapSense_WDGT_STATUS0_VALUE                         (CapSense_dsRam.wdgtStatus[0u])
#define CapSense_WDGT_STATUS0_OFFSET                        (20u)
#define CapSense_WDGT_STATUS0_SIZE                          (4u)
#define CapSense_WDGT_STATUS0_PARAM_ID                      (0xCC000014u)

#define CapSense_SNS_STATUS0_VALUE                          (CapSense_dsRam.snsStatus[0u])
#define CapSense_SNS_STATUS0_OFFSET                         (24u)
#define CapSense_SNS_STATUS0_SIZE                           (1u)
#define CapSense_SNS_STATUS0_PARAM_ID                       (0x48000018u)

#define CapSense_SNS_STATUS1_VALUE                          (CapSense_dsRam.snsStatus[1u])
#define CapSense_SNS_STATUS1_OFFSET                         (25u)
#define CapSense_SNS_STATUS1_SIZE                           (1u)
#define CapSense_SNS_STATUS1_PARAM_ID                       (0x4E000019u)

#define CapSense_CSD0_CONFIG_VALUE                          (CapSense_dsRam.csd0Config)
#define CapSense_CSD0_CONFIG_OFFSET                         (26u)
#define CapSense_CSD0_CONFIG_SIZE                           (2u)
#define CapSense_CSD0_CONFIG_PARAM_ID                       (0xAA80001Au)

#define CapSense_MOD_CSD_CLK_VALUE                          (CapSense_dsRam.modCsdClk)
#define CapSense_MOD_CSD_CLK_OFFSET                         (28u)
#define CapSense_MOD_CSD_CLK_SIZE                           (1u)
#define CapSense_MOD_CSD_CLK_PARAM_ID                       (0x6F80001Cu)

#define CapSense_BUTTON08_RESOLUTION_VALUE                  (CapSense_dsRam.wdgtList.button08.resolution)
#define CapSense_BUTTON08_RESOLUTION_OFFSET                 (30u)
#define CapSense_BUTTON08_RESOLUTION_SIZE                   (2u)
#define CapSense_BUTTON08_RESOLUTION_PARAM_ID               (0x8080001Eu)

#define CapSense_BUTTON08_FINGER_TH_VALUE                   (CapSense_dsRam.wdgtList.button08.fingerTh)
#define CapSense_BUTTON08_FINGER_TH_OFFSET                  (32u)
#define CapSense_BUTTON08_FINGER_TH_SIZE                    (2u)
#define CapSense_BUTTON08_FINGER_TH_PARAM_ID                (0x80800020u)

#define CapSense_BUTTON08_NOISE_TH_VALUE                    (CapSense_dsRam.wdgtList.button08.noiseTh)
#define CapSense_BUTTON08_NOISE_TH_OFFSET                   (34u)
#define CapSense_BUTTON08_NOISE_TH_SIZE                     (1u)
#define CapSense_BUTTON08_NOISE_TH_PARAM_ID                 (0x44800022u)

#define CapSense_BUTTON08_NNOISE_TH_VALUE                   (CapSense_dsRam.wdgtList.button08.nNoiseTh)
#define CapSense_BUTTON08_NNOISE_TH_OFFSET                  (35u)
#define CapSense_BUTTON08_NNOISE_TH_SIZE                    (1u)
#define CapSense_BUTTON08_NNOISE_TH_PARAM_ID                (0x42800023u)

#define CapSense_BUTTON08_HYSTERESIS_VALUE                  (CapSense_dsRam.wdgtList.button08.hysteresis)
#define CapSense_BUTTON08_HYSTERESIS_OFFSET                 (36u)
#define CapSense_BUTTON08_HYSTERESIS_SIZE                   (1u)
#define CapSense_BUTTON08_HYSTERESIS_PARAM_ID               (0x49800024u)

#define CapSense_BUTTON08_ON_DEBOUNCE_VALUE                 (CapSense_dsRam.wdgtList.button08.onDebounce)
#define CapSense_BUTTON08_ON_DEBOUNCE_OFFSET                (37u)
#define CapSense_BUTTON08_ON_DEBOUNCE_SIZE                  (1u)
#define CapSense_BUTTON08_ON_DEBOUNCE_PARAM_ID              (0x4F800025u)

#define CapSense_BUTTON08_LOW_BSLN_RST_VALUE                (CapSense_dsRam.wdgtList.button08.lowBslnRst)
#define CapSense_BUTTON08_LOW_BSLN_RST_OFFSET               (38u)
#define CapSense_BUTTON08_LOW_BSLN_RST_SIZE                 (1u)
#define CapSense_BUTTON08_LOW_BSLN_RST_PARAM_ID             (0x45800026u)

#define CapSense_BUTTON08_IDAC_MOD0_VALUE                   (CapSense_dsRam.wdgtList.button08.idacMod[0u])
#define CapSense_BUTTON08_IDAC_MOD0_OFFSET                  (39u)
#define CapSense_BUTTON08_IDAC_MOD0_SIZE                    (1u)
#define CapSense_BUTTON08_IDAC_MOD0_PARAM_ID                (0x4E000027u)

#define CapSense_BUTTON08_IDAC_GAIN_INDEX_VALUE             (CapSense_dsRam.wdgtList.button08.idacGainIndex)
#define CapSense_BUTTON08_IDAC_GAIN_INDEX_OFFSET            (40u)
#define CapSense_BUTTON08_IDAC_GAIN_INDEX_SIZE              (1u)
#define CapSense_BUTTON08_IDAC_GAIN_INDEX_PARAM_ID          (0x4A800028u)

#define CapSense_BUTTON08_SNS_CLK_VALUE                     (CapSense_dsRam.wdgtList.button08.snsClk)
#define CapSense_BUTTON08_SNS_CLK_OFFSET                    (42u)
#define CapSense_BUTTON08_SNS_CLK_SIZE                      (2u)
#define CapSense_BUTTON08_SNS_CLK_PARAM_ID                  (0x8E80002Au)

#define CapSense_BUTTON08_SNS_CLK_SOURCE_VALUE              (CapSense_dsRam.wdgtList.button08.snsClkSource)
#define CapSense_BUTTON08_SNS_CLK_SOURCE_OFFSET             (44u)
#define CapSense_BUTTON08_SNS_CLK_SOURCE_SIZE               (1u)
#define CapSense_BUTTON08_SNS_CLK_SOURCE_PARAM_ID           (0x4B80002Cu)

#define CapSense_BUTTON08_FINGER_CAP_VALUE                  (CapSense_dsRam.wdgtList.button08.fingerCap)
#define CapSense_BUTTON08_FINGER_CAP_OFFSET                 (46u)
#define CapSense_BUTTON08_FINGER_CAP_SIZE                   (2u)
#define CapSense_BUTTON08_FINGER_CAP_PARAM_ID               (0xA900002Eu)

#define CapSense_BUTTON08_SIGPFC_VALUE                      (CapSense_dsRam.wdgtList.button08.sigPFC)
#define CapSense_BUTTON08_SIGPFC_OFFSET                     (48u)
#define CapSense_BUTTON08_SIGPFC_SIZE                       (2u)
#define CapSense_BUTTON08_SIGPFC_PARAM_ID                   (0xA3000030u)

#define CapSense_BUTTON07_RESOLUTION_VALUE                  (CapSense_dsRam.wdgtList.button07.resolution)
#define CapSense_BUTTON07_RESOLUTION_OFFSET                 (50u)
#define CapSense_BUTTON07_RESOLUTION_SIZE                   (2u)
#define CapSense_BUTTON07_RESOLUTION_PARAM_ID               (0x8A810032u)

#define CapSense_BUTTON07_FINGER_TH_VALUE                   (CapSense_dsRam.wdgtList.button07.fingerTh)
#define CapSense_BUTTON07_FINGER_TH_OFFSET                  (52u)
#define CapSense_BUTTON07_FINGER_TH_SIZE                    (2u)
#define CapSense_BUTTON07_FINGER_TH_PARAM_ID                (0x87810034u)

#define CapSense_BUTTON07_NOISE_TH_VALUE                    (CapSense_dsRam.wdgtList.button07.noiseTh)
#define CapSense_BUTTON07_NOISE_TH_OFFSET                   (54u)
#define CapSense_BUTTON07_NOISE_TH_SIZE                     (1u)
#define CapSense_BUTTON07_NOISE_TH_PARAM_ID                 (0x43810036u)

#define CapSense_BUTTON07_NNOISE_TH_VALUE                   (CapSense_dsRam.wdgtList.button07.nNoiseTh)
#define CapSense_BUTTON07_NNOISE_TH_OFFSET                  (55u)
#define CapSense_BUTTON07_NNOISE_TH_SIZE                    (1u)
#define CapSense_BUTTON07_NNOISE_TH_PARAM_ID                (0x45810037u)

#define CapSense_BUTTON07_HYSTERESIS_VALUE                  (CapSense_dsRam.wdgtList.button07.hysteresis)
#define CapSense_BUTTON07_HYSTERESIS_OFFSET                 (56u)
#define CapSense_BUTTON07_HYSTERESIS_SIZE                   (1u)
#define CapSense_BUTTON07_HYSTERESIS_PARAM_ID               (0x4C810038u)

#define CapSense_BUTTON07_ON_DEBOUNCE_VALUE                 (CapSense_dsRam.wdgtList.button07.onDebounce)
#define CapSense_BUTTON07_ON_DEBOUNCE_OFFSET                (57u)
#define CapSense_BUTTON07_ON_DEBOUNCE_SIZE                  (1u)
#define CapSense_BUTTON07_ON_DEBOUNCE_PARAM_ID              (0x4A810039u)

#define CapSense_BUTTON07_LOW_BSLN_RST_VALUE                (CapSense_dsRam.wdgtList.button07.lowBslnRst)
#define CapSense_BUTTON07_LOW_BSLN_RST_OFFSET               (58u)
#define CapSense_BUTTON07_LOW_BSLN_RST_SIZE                 (1u)
#define CapSense_BUTTON07_LOW_BSLN_RST_PARAM_ID             (0x4081003Au)

#define CapSense_BUTTON07_IDAC_MOD0_VALUE                   (CapSense_dsRam.wdgtList.button07.idacMod[0u])
#define CapSense_BUTTON07_IDAC_MOD0_OFFSET                  (59u)
#define CapSense_BUTTON07_IDAC_MOD0_SIZE                    (1u)
#define CapSense_BUTTON07_IDAC_MOD0_PARAM_ID                (0x4B01003Bu)

#define CapSense_BUTTON07_IDAC_GAIN_INDEX_VALUE             (CapSense_dsRam.wdgtList.button07.idacGainIndex)
#define CapSense_BUTTON07_IDAC_GAIN_INDEX_OFFSET            (60u)
#define CapSense_BUTTON07_IDAC_GAIN_INDEX_SIZE              (1u)
#define CapSense_BUTTON07_IDAC_GAIN_INDEX_PARAM_ID          (0x4D81003Cu)

#define CapSense_BUTTON07_SNS_CLK_VALUE                     (CapSense_dsRam.wdgtList.button07.snsClk)
#define CapSense_BUTTON07_SNS_CLK_OFFSET                    (62u)
#define CapSense_BUTTON07_SNS_CLK_SIZE                      (2u)
#define CapSense_BUTTON07_SNS_CLK_PARAM_ID                  (0x8981003Eu)

#define CapSense_BUTTON07_SNS_CLK_SOURCE_VALUE              (CapSense_dsRam.wdgtList.button07.snsClkSource)
#define CapSense_BUTTON07_SNS_CLK_SOURCE_OFFSET             (64u)
#define CapSense_BUTTON07_SNS_CLK_SOURCE_SIZE               (1u)
#define CapSense_BUTTON07_SNS_CLK_SOURCE_PARAM_ID           (0x4C810040u)

#define CapSense_BUTTON07_FINGER_CAP_VALUE                  (CapSense_dsRam.wdgtList.button07.fingerCap)
#define CapSense_BUTTON07_FINGER_CAP_OFFSET                 (66u)
#define CapSense_BUTTON07_FINGER_CAP_SIZE                   (2u)
#define CapSense_BUTTON07_FINGER_CAP_PARAM_ID               (0xAE010042u)

#define CapSense_BUTTON07_SIGPFC_VALUE                      (CapSense_dsRam.wdgtList.button07.sigPFC)
#define CapSense_BUTTON07_SIGPFC_OFFSET                     (68u)
#define CapSense_BUTTON07_SIGPFC_SIZE                       (2u)
#define CapSense_BUTTON07_SIGPFC_PARAM_ID                   (0xA3010044u)

#define CapSense_BUTTON08_SNS0_RAW0_VALUE                   (CapSense_dsRam.snsList.button08[0u].raw[0u])
#define CapSense_BUTTON08_SNS0_RAW0_OFFSET                  (70u)
#define CapSense_BUTTON08_SNS0_RAW0_SIZE                    (2u)
#define CapSense_BUTTON08_SNS0_RAW0_PARAM_ID                (0x87000046u)

#define CapSense_BUTTON08_SNS0_BSLN0_VALUE                  (CapSense_dsRam.snsList.button08[0u].bsln[0u])
#define CapSense_BUTTON08_SNS0_BSLN0_OFFSET                 (72u)
#define CapSense_BUTTON08_SNS0_BSLN0_SIZE                   (2u)
#define CapSense_BUTTON08_SNS0_BSLN0_PARAM_ID               (0x88000048u)

#define CapSense_BUTTON08_SNS0_BSLN_EXT0_VALUE              (CapSense_dsRam.snsList.button08[0u].bslnExt[0u])
#define CapSense_BUTTON08_SNS0_BSLN_EXT0_OFFSET             (74u)
#define CapSense_BUTTON08_SNS0_BSLN_EXT0_SIZE               (1u)
#define CapSense_BUTTON08_SNS0_BSLN_EXT0_PARAM_ID           (0x4C00004Au)

#define CapSense_BUTTON08_SNS0_DIFF_VALUE                   (CapSense_dsRam.snsList.button08[0u].diff)
#define CapSense_BUTTON08_SNS0_DIFF_OFFSET                  (76u)
#define CapSense_BUTTON08_SNS0_DIFF_SIZE                    (2u)
#define CapSense_BUTTON08_SNS0_DIFF_PARAM_ID                (0x8900004Cu)

#define CapSense_BUTTON08_SNS0_NEG_BSLN_RST_CNT0_VALUE      (CapSense_dsRam.snsList.button08[0u].negBslnRstCnt[0u])
#define CapSense_BUTTON08_SNS0_NEG_BSLN_RST_CNT0_OFFSET     (78u)
#define CapSense_BUTTON08_SNS0_NEG_BSLN_RST_CNT0_SIZE       (1u)
#define CapSense_BUTTON08_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID   (0x4D00004Eu)

#define CapSense_BUTTON08_SNS0_IDAC_COMP0_VALUE             (CapSense_dsRam.snsList.button08[0u].idacComp[0u])
#define CapSense_BUTTON08_SNS0_IDAC_COMP0_OFFSET            (79u)
#define CapSense_BUTTON08_SNS0_IDAC_COMP0_SIZE              (1u)
#define CapSense_BUTTON08_SNS0_IDAC_COMP0_PARAM_ID          (0x4B00004Fu)

#define CapSense_BUTTON07_SNS0_RAW0_VALUE                   (CapSense_dsRam.snsList.button07[0u].raw[0u])
#define CapSense_BUTTON07_SNS0_RAW0_OFFSET                  (80u)
#define CapSense_BUTTON07_SNS0_RAW0_SIZE                    (2u)
#define CapSense_BUTTON07_SNS0_RAW0_PARAM_ID                (0x8F000050u)

#define CapSense_BUTTON07_SNS0_BSLN0_VALUE                  (CapSense_dsRam.snsList.button07[0u].bsln[0u])
#define CapSense_BUTTON07_SNS0_BSLN0_OFFSET                 (82u)
#define CapSense_BUTTON07_SNS0_BSLN0_SIZE                   (2u)
#define CapSense_BUTTON07_SNS0_BSLN0_PARAM_ID               (0x83000052u)

#define CapSense_BUTTON07_SNS0_BSLN_EXT0_VALUE              (CapSense_dsRam.snsList.button07[0u].bslnExt[0u])
#define CapSense_BUTTON07_SNS0_BSLN_EXT0_OFFSET             (84u)
#define CapSense_BUTTON07_SNS0_BSLN_EXT0_SIZE               (1u)
#define CapSense_BUTTON07_SNS0_BSLN_EXT0_PARAM_ID           (0x46000054u)

#define CapSense_BUTTON07_SNS0_DIFF_VALUE                   (CapSense_dsRam.snsList.button07[0u].diff)
#define CapSense_BUTTON07_SNS0_DIFF_OFFSET                  (86u)
#define CapSense_BUTTON07_SNS0_DIFF_SIZE                    (2u)
#define CapSense_BUTTON07_SNS0_DIFF_PARAM_ID                (0x82000056u)

#define CapSense_BUTTON07_SNS0_NEG_BSLN_RST_CNT0_VALUE      (CapSense_dsRam.snsList.button07[0u].negBslnRstCnt[0u])
#define CapSense_BUTTON07_SNS0_NEG_BSLN_RST_CNT0_OFFSET     (88u)
#define CapSense_BUTTON07_SNS0_NEG_BSLN_RST_CNT0_SIZE       (1u)
#define CapSense_BUTTON07_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID   (0x45000058u)

#define CapSense_BUTTON07_SNS0_IDAC_COMP0_VALUE             (CapSense_dsRam.snsList.button07[0u].idacComp[0u])
#define CapSense_BUTTON07_SNS0_IDAC_COMP0_OFFSET            (89u)
#define CapSense_BUTTON07_SNS0_IDAC_COMP0_SIZE              (1u)
#define CapSense_BUTTON07_SNS0_IDAC_COMP0_PARAM_ID          (0x43000059u)

#define CapSense_SNR_TEST_WIDGET_ID_VALUE                   (CapSense_dsRam.snrTestWidgetId)
#define CapSense_SNR_TEST_WIDGET_ID_OFFSET                  (90u)
#define CapSense_SNR_TEST_WIDGET_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_WIDGET_ID_PARAM_ID                (0x6200005Au)

#define CapSense_SNR_TEST_SENSOR_ID_VALUE                   (CapSense_dsRam.snrTestSensorId)
#define CapSense_SNR_TEST_SENSOR_ID_OFFSET                  (91u)
#define CapSense_SNR_TEST_SENSOR_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_SENSOR_ID_PARAM_ID                (0x6400005Bu)

#define CapSense_SNR_TEST_SCAN_COUNTER_VALUE                (CapSense_dsRam.snrTestScanCounter)
#define CapSense_SNR_TEST_SCAN_COUNTER_OFFSET               (92u)
#define CapSense_SNR_TEST_SCAN_COUNTER_SIZE                 (2u)
#define CapSense_SNR_TEST_SCAN_COUNTER_PARAM_ID             (0x8C00005Cu)

#define CapSense_SNR_TEST_RAW_COUNT0_VALUE                  (CapSense_dsRam.snrTestRawCount[0u])
#define CapSense_SNR_TEST_RAW_COUNT0_OFFSET                 (94u)
#define CapSense_SNR_TEST_RAW_COUNT0_SIZE                   (2u)
#define CapSense_SNR_TEST_RAW_COUNT0_PARAM_ID               (0x8000005Eu)

#define CapSense_SCAN_CSD_ISC_VALUE                         (CapSense_dsRam.scanCsdISC)
#define CapSense_SCAN_CSD_ISC_OFFSET                        (96u)
#define CapSense_SCAN_CSD_ISC_SIZE                          (1u)
#define CapSense_SCAN_CSD_ISC_PARAM_ID                      (0x48000060u)

#define CapSense_SCAN_CURRENT_ISC_VALUE                     (CapSense_dsRam.scanCurrentISC)
#define CapSense_SCAN_CURRENT_ISC_OFFSET                    (97u)
#define CapSense_SCAN_CURRENT_ISC_SIZE                      (1u)
#define CapSense_SCAN_CURRENT_ISC_PARAM_ID                  (0x4E000061u)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define CapSense_BUTTON08_PTR2SNS_FLASH_VALUE               (CapSense_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define CapSense_BUTTON08_PTR2SNS_FLASH_OFFSET              (0u)
#define CapSense_BUTTON08_PTR2SNS_FLASH_SIZE                (4u)
#define CapSense_BUTTON08_PTR2SNS_FLASH_PARAM_ID            (0xD1000000u)

#define CapSense_BUTTON08_PTR2WD_RAM_VALUE                  (CapSense_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define CapSense_BUTTON08_PTR2WD_RAM_OFFSET                 (4u)
#define CapSense_BUTTON08_PTR2WD_RAM_SIZE                   (4u)
#define CapSense_BUTTON08_PTR2WD_RAM_PARAM_ID               (0xD0000004u)

#define CapSense_BUTTON08_PTR2SNS_RAM_VALUE                 (CapSense_dsFlash.wdgtArray[0].ptr2SnsRam)
#define CapSense_BUTTON08_PTR2SNS_RAM_OFFSET                (8u)
#define CapSense_BUTTON08_PTR2SNS_RAM_SIZE                  (4u)
#define CapSense_BUTTON08_PTR2SNS_RAM_PARAM_ID              (0xD3000008u)

#define CapSense_BUTTON08_PTR2FLTR_HISTORY_VALUE            (CapSense_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define CapSense_BUTTON08_PTR2FLTR_HISTORY_OFFSET           (12u)
#define CapSense_BUTTON08_PTR2FLTR_HISTORY_SIZE             (4u)
#define CapSense_BUTTON08_PTR2FLTR_HISTORY_PARAM_ID         (0xD200000Cu)

#define CapSense_BUTTON08_PTR2DEBOUNCE_VALUE                (CapSense_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define CapSense_BUTTON08_PTR2DEBOUNCE_OFFSET               (16u)
#define CapSense_BUTTON08_PTR2DEBOUNCE_SIZE                 (4u)
#define CapSense_BUTTON08_PTR2DEBOUNCE_PARAM_ID             (0xD4000010u)

#define CapSense_BUTTON08_STATIC_CONFIG_VALUE               (CapSense_dsFlash.wdgtArray[0].staticConfig)
#define CapSense_BUTTON08_STATIC_CONFIG_OFFSET              (20u)
#define CapSense_BUTTON08_STATIC_CONFIG_SIZE                (4u)
#define CapSense_BUTTON08_STATIC_CONFIG_PARAM_ID            (0xD5000014u)

#define CapSense_BUTTON08_TOTAL_NUM_SNS_VALUE               (CapSense_dsFlash.wdgtArray[0].totalNumSns)
#define CapSense_BUTTON08_TOTAL_NUM_SNS_OFFSET              (24u)
#define CapSense_BUTTON08_TOTAL_NUM_SNS_SIZE                (2u)
#define CapSense_BUTTON08_TOTAL_NUM_SNS_PARAM_ID            (0x99000018u)

#define CapSense_BUTTON08_TYPE_VALUE                        (CapSense_dsFlash.wdgtArray[0].wdgtType)
#define CapSense_BUTTON08_TYPE_OFFSET                       (26u)
#define CapSense_BUTTON08_TYPE_SIZE                         (1u)
#define CapSense_BUTTON08_TYPE_PARAM_ID                     (0x5D00001Au)

#define CapSense_BUTTON08_NUM_COLS_VALUE                    (CapSense_dsFlash.wdgtArray[0].numCols)
#define CapSense_BUTTON08_NUM_COLS_OFFSET                   (27u)
#define CapSense_BUTTON08_NUM_COLS_SIZE                     (1u)
#define CapSense_BUTTON08_NUM_COLS_PARAM_ID                 (0x5B00001Bu)

#define CapSense_BUTTON08_PTR2NOISE_ENVLP_VALUE             (CapSense_dsFlash.wdgtArray[0].ptr2NoiseEnvlp)
#define CapSense_BUTTON08_PTR2NOISE_ENVLP_OFFSET            (28u)
#define CapSense_BUTTON08_PTR2NOISE_ENVLP_SIZE              (4u)
#define CapSense_BUTTON08_PTR2NOISE_ENVLP_PARAM_ID          (0xD700001Cu)

#define CapSense_BUTTON07_PTR2SNS_FLASH_VALUE               (CapSense_dsFlash.wdgtArray[1].ptr2SnsFlash)
#define CapSense_BUTTON07_PTR2SNS_FLASH_OFFSET              (32u)
#define CapSense_BUTTON07_PTR2SNS_FLASH_SIZE                (4u)
#define CapSense_BUTTON07_PTR2SNS_FLASH_PARAM_ID            (0xD8010020u)

#define CapSense_BUTTON07_PTR2WD_RAM_VALUE                  (CapSense_dsFlash.wdgtArray[1].ptr2WdgtRam)
#define CapSense_BUTTON07_PTR2WD_RAM_OFFSET                 (36u)
#define CapSense_BUTTON07_PTR2WD_RAM_SIZE                   (4u)
#define CapSense_BUTTON07_PTR2WD_RAM_PARAM_ID               (0xD9010024u)

#define CapSense_BUTTON07_PTR2SNS_RAM_VALUE                 (CapSense_dsFlash.wdgtArray[1].ptr2SnsRam)
#define CapSense_BUTTON07_PTR2SNS_RAM_OFFSET                (40u)
#define CapSense_BUTTON07_PTR2SNS_RAM_SIZE                  (4u)
#define CapSense_BUTTON07_PTR2SNS_RAM_PARAM_ID              (0xDA010028u)

#define CapSense_BUTTON07_PTR2FLTR_HISTORY_VALUE            (CapSense_dsFlash.wdgtArray[1].ptr2FltrHistory)
#define CapSense_BUTTON07_PTR2FLTR_HISTORY_OFFSET           (44u)
#define CapSense_BUTTON07_PTR2FLTR_HISTORY_SIZE             (4u)
#define CapSense_BUTTON07_PTR2FLTR_HISTORY_PARAM_ID         (0xDB01002Cu)

#define CapSense_BUTTON07_PTR2DEBOUNCE_VALUE                (CapSense_dsFlash.wdgtArray[1].ptr2DebounceArr)
#define CapSense_BUTTON07_PTR2DEBOUNCE_OFFSET               (48u)
#define CapSense_BUTTON07_PTR2DEBOUNCE_SIZE                 (4u)
#define CapSense_BUTTON07_PTR2DEBOUNCE_PARAM_ID             (0xDD010030u)

#define CapSense_BUTTON07_STATIC_CONFIG_VALUE               (CapSense_dsFlash.wdgtArray[1].staticConfig)
#define CapSense_BUTTON07_STATIC_CONFIG_OFFSET              (52u)
#define CapSense_BUTTON07_STATIC_CONFIG_SIZE                (4u)
#define CapSense_BUTTON07_STATIC_CONFIG_PARAM_ID            (0xDC010034u)

#define CapSense_BUTTON07_TOTAL_NUM_SNS_VALUE               (CapSense_dsFlash.wdgtArray[1].totalNumSns)
#define CapSense_BUTTON07_TOTAL_NUM_SNS_OFFSET              (56u)
#define CapSense_BUTTON07_TOTAL_NUM_SNS_SIZE                (2u)
#define CapSense_BUTTON07_TOTAL_NUM_SNS_PARAM_ID            (0x90010038u)

#define CapSense_BUTTON07_TYPE_VALUE                        (CapSense_dsFlash.wdgtArray[1].wdgtType)
#define CapSense_BUTTON07_TYPE_OFFSET                       (58u)
#define CapSense_BUTTON07_TYPE_SIZE                         (1u)
#define CapSense_BUTTON07_TYPE_PARAM_ID                     (0x5401003Au)

#define CapSense_BUTTON07_NUM_COLS_VALUE                    (CapSense_dsFlash.wdgtArray[1].numCols)
#define CapSense_BUTTON07_NUM_COLS_OFFSET                   (59u)
#define CapSense_BUTTON07_NUM_COLS_SIZE                     (1u)
#define CapSense_BUTTON07_NUM_COLS_PARAM_ID                 (0x5201003Bu)

#define CapSense_BUTTON07_PTR2NOISE_ENVLP_VALUE             (CapSense_dsFlash.wdgtArray[1].ptr2NoiseEnvlp)
#define CapSense_BUTTON07_PTR2NOISE_ENVLP_OFFSET            (60u)
#define CapSense_BUTTON07_PTR2NOISE_ENVLP_SIZE              (4u)
#define CapSense_BUTTON07_PTR2NOISE_ENVLP_PARAM_ID          (0xDE01003Cu)


#endif /* End CY_SENSE_CapSense_REGISTER_MAP_H */


/* [] END OF FILE */
